| circleCub.Gauss | R Documentation |
This function calculates the integral of the bivariate, isotropic Gaussian
density (i.e., \Sigma = sd^2*diag(2)) over a circular domain
via the cumulative distribution function pchisq of the (non-central)
Chi-Squared distribution \bibcitep|R:Abramowitz+Stegun:1972|Formula 26.3.24.
circleCub.Gauss(center, r, mean, sd)
center |
numeric vector of length 2 (center of the circle). |
r |
numeric (radius of the circle). Several radii may be supplied. |
mean |
numeric vector of length 2 (mean of the bivariate Gaussian density). |
sd |
numeric (common standard deviation of the isotropic Gaussian density in both dimensions). |
The integral value (one for each supplied radius).
The non-centrality parameter of the evaluated chi-squared distribution
equals the squared distance between the mean and the
center. If this becomes too large, the result becomes inaccurate, see
pchisq.
*
circleCub.Gauss(center=c(1,2), r=3, mean=c(4,5), sd=6)
## compare with cubature over a polygonal approximation of a circle
d2norm <- function (s, mean, sd)
dnorm(s[,1], mean=mean[1], sd=sd) * dnorm(s[,2], mean=mean[2], sd=sd)
if (requireNamespace("spatstat.geom")) { # for the disc()
npoly <- 32 # increase this for a closer match
disc.poly <- spatstat.geom::disc(radius=3, centre=c(1,2), npoly=npoly)
polyCub.iso(disc.poly, d2norm, mean=c(4,5), sd=6, center=c(4,5))
}
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.