polyCub-package: Cubature over Polygonal Domains

polyCub-packageR Documentation

Cubature over Polygonal Domains

Description

The R package polyCub \bibcitepCITATION implements cubature (numerical integration) over polygonal domains. It solves the problem of integrating a continuously differentiable function f(x,y) over simple closed polygons.

Details

polyCub provides the following cubature methods:

polyCub.SV:

General-purpose product Gauss cubature \bibcitepsommariva.vianello2007

polyCub.midpoint:

Simple two-dimensional midpoint rule based on as.im.function from spatstat.geom (Baddeley et al. 2015)

polyCub.iso:

Adaptive cubature for radially symmetric functions via line integrate() along the polygon boundary \bibcitep|meyer.held2014|Supplement B, Section 2.4

A brief description and benchmark experiment of the above cubature methods can be found in the vignette("polyCub").

There is also polyCub.exact.Gauss, intended to accurately (but slowly) integrate the bivariate Gaussian density; however, this implementation is disabled as of polyCub 0.9.0: it needs a reliable implementation of polygon triangulation.

\bibcitet

|meyer2010|Section 3.2 discusses and compares some of these methods.

Author(s)

Sebastian Meyer

References

Baddeley A, Rubak E, Turner R (2015). Spatial Point Patterns: Methodology and Applications with R. Chapman and Hall/CRC Press, London.

\bibshow

*

See Also

vignette("polyCub")

For the special case of a rectangular domain along the axes (e.g., a bounding box), the cubature package is more appropriate.


polyCub documentation built on April 11, 2026, 9:06 a.m.