"xylist", which represents
polygons by their core feature only, a list of lists of vertex coordinates
(see the "Value" section below).
The generic function xylist can deal with the
following polygon classes:
"owin"from package"gpc.poly" from package
"Polygons" from package "Polygon" and
"SpatialPolygons")xylist(object, ...)## S3 method for class 'owin':
xylist(object, ...)
## S3 method for class 'gpc.poly':
xylist(object, ...)
## S3 method for class 'SpatialPolygons':
xylist(object, reverse = TRUE, ...)
## S3 method for class 'Polygons':
xylist(object, reverse = TRUE, ...)
## S3 method for class 'Polygon':
xylist(object, reverse = TRUE, ...)
## S3 method for class 'default':
xylist(object, ...)
TRUE) indicating if the vertex order of the
xylist/owin
convention.xylist to a polygon object, one gets a simple list,
where each component (polygon) is a list of "x" and "y"
coordinates. These represent vertex coordinates following "owin" convention (anticlockwise order without repeating any vertex).
The opposite vertex order can be retained for the reverse=FALSE.xylistxylist."gpc.poly".